multidim.models.GaussianMixtureClassifier.predict — GDA Toolbox v1.0 Manual

# multidim.models.GaussianMixtureClassifier.predict

`GaussianMixtureClassifier.` `predict`(pointclouds)

  Predict labels of given pointclouds, based on previous training data fed to `fit()`.

  This is just a call to `runit()`

  Parameters: | pointclouds : list-like A list of arrays. Each array is a pointcloud. Each row of that array is a point.
  Returns: | array of labels, one for each pointcloud in the input list.

#### Previous topic

multidim.models.GaussianMixtureClassifier.plot

#### Next topic

multidim.models.GaussianMixtureClassifier.runit